@@ -1,6 +1,6 @@
 package Farabi::Plugin::PerlTidy;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 sub new {
 	return bless {};
@@ -16,7 +16,11 @@ sub plugin_name {
 __END__
 
 =pod
-s
+
+=head1 NAME
+
+Farabi::Plugin::PerlTidy - Perl::Tidy support for Farabi
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012-2013 by Ahmad M. Zawawi
