@@ -64,15 +64,10 @@ $(function() {
 		// Add the tab editor
 		$("#myTabContent").append(
 			'<div class="tab-pane" id="' + tabId + '">' +
-				'<div class="span6 farabi-bordered" id="editor-border">' +
+				'<div class="farabi-bordered" id="editor-border">' +
 					'<textarea id="'+editorId+'" name="' + editorId +'" class="editor"></textarea>' +
 					'<div class="editor_stats" class="pull-right"></div>' +
 				'</div>' +
-				'<div class="span6 farabi-bordered">' +
-					'<b>POD  Preview:</b>' + 
-					'<div  id="pod-tab">' +
-					'</div>' +
-				'</div>' +
 			'</div>');
 			
 		$("i", "#myTab").mouseover(function() {
@@ -497,7 +492,16 @@ $(function() {
 	// Handle the dump ppi tree action
 	$(document).on('action-dump-ppi-tree', function() {
 		var editor = GetCurrentEditor();
-		$.post('/dump-ppi-tree', {"source": editor.getValue()}, function(data) {
+		$("#output").val("'" + editor.getSelection() + "'");
+
+		// Get the editor selection and fallback to
+		// all editor contents
+		var source = editor.getSelection();
+		if(source == '') {
+			source = editor.getValue();
+		}
+
+		$.post('/dump-ppi-tree', {"source": source}, function(data) {
 			if(data.error == '') {
 				$("#output").val(data.output);
 			} else {
